<?php

declare(strict_types=1);

/**
 * This file is part of the TWB5Widgets package
 *
 * https://github.com/VitexSoftware/php-ease-twbootstrap5-widgets
 *
 * (c) Vítězslav Dvořák <http://vitexsoftware.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Ease\TWB5\Widgets;

use Ease\TWB5\Row;
use \Ease\Html\DivTag;

class MainPageMenu extends Row
{
    /**
     * Sem se přidávají položky.
     */
    public DivTag $row;

    /**
     * MainPage Menu.
     */
    public function __construct()
    {
        parent::__construct(
            null,
            [],
            [
                'class' => 'container',
                'style' => 'margin: auto;',
            ],
        );
    }

    /**
     * Add Item to mainpage Menu.
     *
     * @param string     $title       caption
     * @param string     $url         image link href url
     * @param string     $image       url
     * @param mixed      $description
     * @param null|mixed $buttonText
     * @param array      $properties  for Card
     *
     * @return \Ease\Html\ATag
     */
    public function addMenuItem($title, $url, $image, $description, $buttonText = null, $properties = []): Row
    {
        $icon = new \Ease\Html\ImgTag($image, $title, ['alt' => $title, 'class' => 'card-img-top']);
        // $cardHeader = new \Ease\Html\DivTag($title, ['class' => 'card-header']);
        $cardBody = new \Ease\Html\DivTag(new \Ease\Html\H5Tag($title), ['class' => 'card-body']);
        $cardBody->addItem(new \Ease\Html\PTag($description, ['class' => 'card-text']));
        $cardBody->addItem(new \Ease\TWB5\LinkButton($url, empty($buttonText) ? _('Visit') : $buttonText, 'primary btn-block'));
        $menuCard = new \Ease\TWB5\Card([$icon, $cardBody], $properties);

        return $this->addItem(new \Ease\TWB5\Col(3, $menuCard));
    }
}
